FdReader2

Struct FdReader2 

pub struct FdReader2<S> { /* private fields */ }
Input function that reads from a file descriptor

An instance of FdReader2<S> contains a system of type S that is used to read from the file descriptor. The system must implement the Read trait to allow the reading operation.

Although FdReader2 implements Clone, cloning an instance does not allow you to replay the input later. If the system is contained in Rc, for example, reading from one instance will affect subsequent reads from the other, since they share the same system and file descriptor.

This struct is named FdReader2 to distinguish it from FdReader, an older implementation that existed before the Concurrent system was implemented. The FdReader struct has been removed, but the name FdReader2 is kept for backward compatibility.

Implementations

Source

impl<S> FdReader2<S>

pub fn new(fd: Fd, system: S) -> Self

Creates a new FdReader2 instance.

The fd argument is the file descriptor to read from. It should be readable, have the close-on-exec flag set, and remain open for the lifetime of the FdReader2 instance.