#[non_exhaustive]pub struct SuspendedJobsGuardConfig {
pub message: String,
}Expand description
Configuration for the suspended-jobs exit guard.
When present in Env::any, EofGuard refuses to exit
when there are suspended jobs, printing message to warn
the user. Other components may also opt in to this protection by checking
for this config.
Store this config in the environment with
env.any.insert(Box::new(config)).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message: StringText displayed when exit is prevented because there are suspended jobs
Implementations
Sourceimpl SuspendedJobsGuardConfig
impl SuspendedJobsGuardConfig
Sourcepub fn with_message<M: Into<String>>(message: M) -> Self
pub fn with_message<M: Into<String>>(message: M) -> Self
Creates a new SuspendedJobsGuardConfig with the given message.