#[non_exhaustive]pub enum Error {
NotFound,
Unusable(Unusable),
}Expand description
Reason why the command search did not yield a target
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotFound
No command was found with the given name.
Unusable(Unusable)
A built-in was found, but it cannot be executed.
Note that the shell must not fall back to an external utility in this case: the built-in was found, so the command search is over.
Implementations
Sourceimpl Error
impl Error
Sourcepub const fn exit_status(self) -> ExitStatus
pub const fn exit_status(self) -> ExitStatus
Returns the exit status the shell should produce for this error.
This is 127 if no command was found, and the
Unusable::exit_status if a built-in was found but cannot be
executed.