Module subshell

Module subshell 

Utility for starting subshells

This module defines Config, a builder for starting a subshell. It is a collection of options for starting a subshell, and provides methods to start a subshell with the configured options. These methods are implemented as wrappers around Env::run_in_child_process, which in turn uses Fork::run_in_child_process. You should prefer Config for the purpose of creating a subshell because it helps to arrange the child process properly.

This module also defines a deprecated struct Subshell with a similar API to Config for backward compatibility. New code should use Config instead of Subshell.

Structs

Config
Configuration for subshell creation
SubshellDeprecated
Subshell builder

Enums

JobControl
Job state of a newly created subshell

Traits

BlockSignals
Trait to temporarily block the SIGINT and SIGQUIT signals