CStrPtr

Struct CStrPtr 

pub struct CStrPtr(/* private fields */);
Simple wrapper to treat a raw pointer to an array of C-style strings as a AsCStrArray

This is useful for passing raw pointers obtained from other sources (e.g., FFI) to functions that expect an AsCStrArray. However, it is the caller’s responsibility to ensure that the pointer validly points to a null-terminated array of pointers to valid C-style strings, and that the array and strings remain valid for the required lifetime. This wrapper does not take ownership of the array or strings.

You should prefer BorrowedCStrs or OwnedCStrs over this type when possible, as they provide ownership and lifetime guarantees for the strings.

Implementations

Source

impl CStrPtr

pub unsafe fn new(ptr: *const *const c_char) -> Self

Create a new CStrPtr from a raw pointer to an array of C-style strings.

The given pointer is directly returned by the as_ptr method.

Safety

The caller must ensure that ptr points to a valid null-terminated array of pointers to valid C-style strings. The array and strings must remain valid and unmodified until the CStrPtr is dropped.