Concurrent

Struct Concurrent 

pub struct Concurrent<S: Sigmask> { /* private fields */ }
Decorator for systems that makes blocking I/O operations concurrency-friendly

This struct is used as a wrapper for systems for enabling concurrent execution of multiple possibly blocking I/O tasks on a single thread. The inner system is expected to implement the Read, Write, and super::Select traits with synchronous (blocking) behavior. This struct leaves Futures returned by I/O methods pending until the I/O operation is ready to avoid blocking the entire process. This allows you to start multiple I/O tasks and wait for them to complete concurrently on a single thread. This struct also provides methods for waiting for signals and waiting for a specified duration, which are represented as Futures as well. The select method of this struct consolidates blocking behavior into a single system call so that the process can resume execution as soon as any of the specified events occurs.

For system calls that do not block, such as Pipe, the wrapper directly forwards the call to the inner system without any modification.

This struct is designed to be used in an Rc to allow multiple tasks to share the same concurrent system. Some traits, such as Read and Write, are implemented for Rc<Concurrent<S>> instead of Concurrent<S> to allow the methods to return futures that capture a clone of the Rc and keep it alive until the operation is finished. This is necessary because the futures need to access the internal state of the Concurrent system without capturing a reference to the original Concurrent struct, which may not live long enough.

The following example illustrates how multiple concurrent tasks are run in a single-threaded pool:

let system = Rc::new(Concurrent::new(VirtualSystem::new()));
let system2 = system.clone();
let system3 = system.clone();
let (reader, writer) = system.pipe().unwrap();
let mut executor = futures_executor::LocalPool::new();

// We add a task that tries to read from the pipe, but nothing has been
// written to it, so the task is stalled.
let read_task = executor.spawner().spawn_local_with_handle(async move {
    let mut buffer = [0; 1];
    system.read(reader, &mut buffer).await.unwrap();
    buffer[0]
});
executor.run_until_stalled();

// Let's add a task that writes to the pipe.
executor.spawner().spawn_local(async move {
    system2.write_all(writer, &[123]).await.unwrap();
});
executor.run_until_stalled();

// The write task has written a byte to the pipe, but the read task is still
// stalled. We need to wake it up by calling `select` or `peek`.
system3.peek();

// Now the read task can proceed to the end.
let number = executor.run_until(read_task.unwrap());
assert_eq!(number, 123);

Implementations

Source

impl<S> Concurrent<S>
where S: Fork + Sigmask,

pub fn new_child_process(&self) -> Result<ChildProcessStarter<S>>

👎Deprecated since 0.14.0:

use the Fork::run_in_child_process method instead

Creates a new child process.

Returns the ChildProcessStarter<S> returned by the inner system’s Fork::new_child_process method. This method is an inherent method of Concurrent<S> instead of an implementation of the Fork trait because the return type does not match with that of the inner system S.

Source

impl Concurrent<RealSystem>

pub fn run_real<F, T>(&self, task: F) -> T
where F: Future<Output = T>,

Runs the given task with concurrency support.

This function implements the main loop of the shell process. It runs the given task while also calling select to handle signals and other events. The task is expected to perform I/O operations using the methods of this Concurrent instance, so that it can yield when the operations would block. The function returns the output of the task when it completes.

This method supports concurrency only inside the task. Other tasks created outside the task will not be run concurrently. This method blocks the current thread until the task completes, so it should only be called in the main function of the shell process. See the run_virtual method for the VirtualSystem counterpart.

Source

impl Concurrent<VirtualSystem>

pub async fn run_virtual<F>(&self, task: F)
where F: Future<Output = ()>,

Runs the given task with concurrency support.

This function implements the main loop of the shell process. It runs the given task while also calling select to handle signals and other events. The task is expected to perform I/O operations using the methods of this Concurrent instance, so that it can yield when the operations would block. The function returns when the task completes or the process is terminated.

This is the VirtualSystem counterpart for the run_real method. To allow VirtualSystem to run multiple tasks concurrently, this method is asynchronous and returns a future that completes when the task finishes or the process is terminated.

Source

impl<S: Sigmask> Concurrent<S>

pub fn new(inner: S) -> Self

Creates a new Concurrent system that wraps the given inner system.