Concurrent

Struct Concurrent 

pub struct Concurrent<S> { /* private fields */ }
Decorator for systems that makes blocking I/O operations concurrency-friendly

This struct is used as a wrapper for systems for enabling concurrent execution of multiple possibly blocking I/O tasks on a single thread. The inner system is expected to implement the Read, Write, and Select traits with synchronous (blocking) behavior. This struct leaves Futures returned by I/O methods pending until the I/O operation is ready to avoid blocking the entire process. This allows you to start multiple I/O tasks and wait for them to complete concurrently on a single thread. This struct also provides methods for waiting for signals and waiting for a specified duration, which are represented as Futures as well. The select method of this struct consolidates blocking behavior into a single system call so that the process can resume execution as soon as any of the specified events occurs.

For system calls that do not block, such as Pipe, the wrapper directly forwards the call to the inner system without any modification.

This struct is designed to be used in an Rc to allow multiple tasks to share the same concurrent system. Some traits, such as Read and Write, are implemented for Rc<Concurrent<S>> instead of Concurrent<S> to allow the methods to return futures that capture a clone of the Rc and keep it alive until the operation is finished. This is necessary because the futures need to access the internal state of the Concurrent system without capturing a reference to the original Concurrent struct, which may not live long enough.

The following example illustrates how multiple concurrent tasks are run in a single-threaded pool:

let system = Rc::new(Concurrent::new(VirtualSystem::new()));
let system2 = system.clone();
let system3 = system.clone();
let (reader, writer) = system.pipe().unwrap();
let mut executor = futures_executor::LocalPool::new();

// We add a task that tries to read from the pipe, but nothing has been
// written to it, so the task is stalled.
let read_task = executor.spawner().spawn_local_with_handle(async move {
    let mut buffer = [0; 1];
    system.read(reader, &mut buffer).await.unwrap();
    buffer[0]
});
executor.run_until_stalled();

// Let's add a task that writes to the pipe.
executor.spawner().spawn_local(async move {
    system2.write_all(writer, &[123]).await.unwrap();
});
executor.run_until_stalled();

// The write task has written a byte to the pipe, but the read task is still
// stalled. We need to wake it up by calling `select` or `peek`.
system3.peek();

// Now the read task can proceed to the end.
let number = executor.run_until(read_task.unwrap());
assert_eq!(number, 123);

Implementations

Source

impl<S> Concurrent<S>
where S: Fork,

pub fn new_child_process(&self) -> Result<ChildProcessStarter<S>>

Creates a new child process.

Returns the ChildProcessStarter<S> returned by the inner system’s Fork::new_child_process method. This method is an inherent method of Concurrent<S> instead of an implementation of the Fork trait because the return type does not match with that of the inner system S.

Source

impl Concurrent<RealSystem>

pub fn run_real<F, T>(&self, task: F) -> T
where F: Future<Output = T>,

Runs the given task with concurrency support.

This function implements the main loop of the shell process. It runs the given task while also calling select to handle signals and other events. The task is expected to perform I/O operations using the methods of this Concurrent instance, so that it can yield when the operations would block. The function returns the output of the task when it completes.

This method supports concurrency only inside the task. Other tasks created outside the task will not be run concurrently. This method blocks the current thread until the task completes, so it should only be called in the main function of the shell process. See the run_virtual method for the VirtualSystem counterpart.

Source

impl Concurrent<VirtualSystem>

pub async fn run_virtual<F>(&self, task: F)
where F: Future<Output = ()>,

Runs the given task with concurrency support.

This function implements the main loop of the shell process. It runs the given task while also calling select to handle signals and other events. The task is expected to perform I/O operations using the methods of this Concurrent instance, so that it can yield when the operations would block. The function returns the output of the task when it completes.

This is the VirtualSystem counterpart for the run_real method. To allow VirtualSystem to run multiple tasks concurrently, this method is asynchronous and returns a future that completes when the task finishes or the process is terminated.

Source

impl<S> Concurrent<S>
where S: Fcntl + Read,

pub async fn read_all_to( &self, fd: Fd, buffer: &mut Vec<u8>, ) -> Result<(), Errno>

Reads from the file descriptor until EOF is reached, appending the data to the provided buffer.

In case of an error, the buffer will contain all data read up to the point of failure.

Use read_all if you don’t have an existing buffer to append to.

pub async fn read_all(&self, fd: Fd) -> Result<Vec<u8>, Errno>

Reads from the file descriptor until EOF is reached, returning the collected data as a Vec<u8>.

This is a convenience method that allocates a buffer and calls read_all_to.

Source

impl<S> Concurrent<S>
where S: Fcntl + Write,

pub async fn write_all(&self, fd: Fd, data: &[u8]) -> Result<(), Errno>

Writes all data from the provided buffer to the file descriptor.

This method ensures that all data is written, even if multiple write operations are required due to partial writes.

If the data is empty, this method will return immediately without performing write operations.

pub async fn print_error<T: AsRef<[u8]>>(&self, message: T)

Writes the given message to standard error.

This is a convenience method that calls write_all with Fd::STDERR.

Source

impl<S> Concurrent<S>

pub fn new(inner: S) -> Self

Creates a new Concurrent system that wraps the given inner system.

Source

impl<S> Concurrent<S>
where S: Clock,

pub async fn sleep_until(&self, deadline: Instant)

Waits until the specified deadline.

The returned future will be pending until the specified deadline is reached, at which point it will complete.

pub async fn sleep(&self, duration: Duration)

Waits for the specified duration to elapse.

The returned future will be pending until the specified duration has elapsed, at which point it will complete.

Source

impl<S> Concurrent<S>

pub async fn wait_for_signals(&self) -> Rc<SignalList>

Waits for signals to be caught.

The returned future will be pending until any signal is caught, at which point it will complete with a list of caught signals. The list is shared among all tasks waiting for signals, so that they can see the same list of caught signals when they are woken up.

Before calling this method, the caller needs to set_disposition for the signals it wants to catch.

If this Concurrent system is used in an Env, you should call Env::wait_for_signals instead of this method, so that the trap set can handle the signals properly.

Source

impl<S> Concurrent<S>
where S: CaughtSignals + Clock + Select,

pub fn peek(&self)

Peeks for any ready events without blocking.

This method performs a select system call with the file descriptors and timeout of pending tasks, and wakes the tasks whose events are ready. This method is similar to select, but it does not block and returns immediately.

pub async fn select(&self)

Waits for any of pending tasks to become ready.

This method performs a select system call with the file descriptors and timeout of pending tasks, and wakes the tasks whose events are ready. This method should be called in the main loop of the process to ensure that tasks can make progress. In a typical use case, the main loop would look like this:

loop {
    // Run ready tasks until they yield again
    run_ready_tasks();
    // Wait for any pending task to become ready
    concurrent.select().await;
}

The run_real and run_virtual methods provide a convenient way to implement such a main loop.

The future returned by this method will be pending if and only if the future returned by the inner system’s select method is pending.