SharedSystem

Struct SharedSystem 

pub struct SharedSystem<S>(/* private fields */);
๐Ÿ‘ŽDeprecated since 0.13.0:

use Concurrent instead

System shared by a reference counter.

A SharedSystem is a reference-counted container of a System instance accompanied with an internal state for supporting asynchronous interactions with the system. As it is reference-counted, cloning a SharedSystem instance only increments the reference count without cloning the backing system instance. This behavior allows calling SharedSystemโ€™s methods concurrently from different async tasks that each have a SharedSystem instance sharing the same state.

SharedSystem implements System by delegating to the contained system instance of type S. You should avoid calling some of the System methods, however. Prefer async functions provided by SharedSystem (e.g., read_async) over raw system functions (e.g., read).

The following example illustrates how multiple concurrent tasks are run in a single-threaded pool:

let system = SharedSystem::new(VirtualSystem::new());
let system2 = system.clone();
let system3 = system.clone();
let (reader, writer) = system.pipe().unwrap();
let mut executor = futures_executor::LocalPool::new();

// We add a task that tries to read from the pipe, but nothing has been
// written to it, so the task is stalled.
let read_task = executor.spawner().spawn_local_with_handle(async move {
    let mut buffer = [0; 1];
    system.read_async(reader, &mut buffer).await.unwrap();
    buffer[0]
});
executor.run_until_stalled();

// Let's add a task that writes to the pipe.
executor.spawner().spawn_local(async move {
    system2.write_all(writer, &[123]).await.unwrap();
});
executor.run_until_stalled();

// The write task has written a byte to the pipe, but the read task is still
// stalled. We need to wake it up by calling `select`.
system3.select(false).unwrap();

// Now the read task can proceed to the end.
let number = executor.run_until(read_task.unwrap());
assert_eq!(number, 123);

Implementations

Source

impl<S> SharedSystem<S>

pub fn new(system: S) -> Self

Creates a new shared system.

pub async fn read_async(&self, fd: Fd, buffer: &mut [u8]) -> Result<usize>
where S: Fcntl + Read,

Reads from the file descriptor.

This function waits for one or more bytes to be available for reading. If successful, returns the number of bytes read.

pub async fn write_all(&self, fd: Fd, buffer: &[u8]) -> Result<usize>
where S: Fcntl + Write,

Writes to the file descriptor.

This function calls write repeatedly until the whole buffer is written to the FD. If the buffer is empty, write is not called at all, so any error that would be returned from write is not returned.

This function silently ignores signals that may interrupt writes.

pub async fn print_error(&self, message: &str)
where S: Fcntl + Write,

Convenience function for printing a message to the standard error

pub async fn wait_until(&self, target: Instant)
where S: Clock,

Waits until the specified time point.

pub async fn wait_for_signals(&self) -> Rc<[Number]>

Waits for some signals to be delivered to this process.

Before calling this function, you need to set the signal disposition to Catch. Without doing so, this function cannot detect the receipt of the signals.

Returns an array of signals that were caught.

If this SharedSystem is part of an Env, you should call Env::wait_for_signals rather than calling this function directly so that the trap set can remember the caught signal.

pub async fn wait_for_signal(&self, signal: Number)

Waits for a signal to be delivered to this process.

Before calling this function, you need to set the signal disposition to Catch. Without doing so, this function cannot detect the receipt of the signal.

If this SharedSystem is part of an Env, you should call Env::wait_for_signal rather than calling this function directly so that the trap set can remember the caught signal.

pub fn select(&self, poll: bool) -> Result<()>
where S: Select + CaughtSignals + Clock,

Waits for a next event to occur.

This function calls Select::select with arguments computed from the current internal state of the SharedSystem. It will wake up tasks waiting for the file descriptor to be ready in read_async and write_all or for a signal to be caught in wait_for_signal. If no tasks are woken for FDs or signals and poll is false, this function will block until the first task waiting for a specific time point is woken.

If poll is true, this function does not block, so it may not wake up any tasks.

This function may wake up a task even if the condition it is expecting has not yet been met.

pub async fn select_async(&self) -> Result<()>
where S: Select + CaughtSignals + Clock,

Waits for a next event to occur.

This function calls Select::select with arguments computed from the current internal state of the SharedSystem. It will wake up tasks waiting for the file descriptor to be ready in read_async and write_all or for a signal to be caught in wait_for_signal. If no tasks are woken for FDs or signals, this function simulates blocking by returning Pending from the returned future until the first task waiting for a specific time point is woken.

This function may wake up a task even if the condition it is expecting has not yet been met.

pub fn new_child_process(&self) -> Result<ChildProcessStarter<S>>
where S: Fork,

Creates a new child process.

See Fork::new_child_process for details.