pub trait IsExecutableFile {
// Required method
fn is_executable_file(&self, path: &CStr) -> bool;
}Expand description
Trait for checking if a file is executable
This trait declares the is_executable_file method, which checks whether a
filepath points to an executable regular file. This trait is separate from
the Fstat trait because the implementation depends on the faccessat
system call.
Required Methods
Sourcefn is_executable_file(&self, path: &CStr) -> bool
fn is_executable_file(&self, path: &CStr) -> bool
Whether there is an executable regular file at the specified path.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<S: IsExecutableFile> IsExecutableFile for Rc<S>
Delegates the IsExecutableFile trait to the contained instance of S
impl<S: IsExecutableFile> IsExecutableFile for Rc<S>
Delegates the IsExecutableFile trait to the contained instance of S