ShellPath

Trait ShellPath 

pub trait ShellPath {
    // Required method
    fn shell_path(&self) -> CString;
}
Trait for getting the path to the shell executable

Required Methods

fn shell_path(&self) -> CString

Returns the path to the shell executable.

If possible, this function should return the path to the current shell executable. Otherwise, it should return the path to the default POSIX shell.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<S: ShellPath> ShellPath for Rc<S>

Delegates the ShellPath trait to the contained instance of S

Implementors