FileBody

Enum FileBody 

#[non_exhaustive]
pub enum FileBody { Regular { content: Vec<u8>, is_native_executable: bool, }, Directory { files: HashMap<Rc<UnixStr>, Rc<RefCell<Inode>>>, }, Fifo { content: VecDeque<u8>, readers: usize, writers: usize, pending_open_wakers: WakerSet, pending_read_wakers: WakerSet, pending_write_wakers: WakerSet, }, Symlink { target: PathBuf, }, Terminal { content: Vec<u8>, }, }
Filetype-specific content of a file

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Regular

Regular file

Fields

content: Vec<u8>

File content

is_native_executable: bool

Whether this file is a native binary that can be exec’ed



Directory

Directory

Fields

files: HashMap<Rc<UnixStr>, Rc<RefCell<Inode>>>

Files contained in this directory

The keys of the hashmap are filenames without any parent directory components. The hashmap does not contain “.” or “..”.



Fifo

Named pipe

Fields

content: VecDeque<u8>

Content of the pipe

readers: usize

Number of open file descriptions reading from this pipe

writers: usize

Number of open file descriptions writing to this pipe

pending_open_wakers: WakerSet

Wakers of tasks waiting to open the pipe for reading or writing

A reader and a writer of a pipe are opened synchronously: when a task attempts to open the pipe for reading, it will wait until another task opens the pipe for writing, and vice versa. This field is used to store the wakers of tasks waiting to open the pipe, so that they can be notified when a new reader or writer is opened.

pending_read_wakers: WakerSet

Wakers of tasks waiting to read from the pipe

When a task attempts to read from an empty pipe, it will wait until another task writes to the pipe. This field is used to store the wakers of such tasks, so that they can be notified when new content is written.

pending_write_wakers: WakerSet

Wakers of tasks waiting to write to the pipe

When a task attempts to write to a full pipe, it will wait until another task reads from the pipe. This field is used to store the wakers of such tasks, so that they can be notified when content is read and space is available for writing.

Symbolic link

Fields

target: PathBuf

Path to the file referenced by this symlink



Terminal

Terminal device

This is a dummy device that works like a regular file.

Fields

content: Vec<u8>

Virtual file content

Implementations

Source

impl FileBody

pub fn new<T: Into<Vec<u8>>>(bytes: T) -> Self

Creates a regular file body with the given content.

pub const fn type(&self) -> FileType

Returns the type of the file.

pub fn size(&self) -> usize

Returns the size of the file.

pub fn is_seekable(&self) -> bool

Returns whether the file supports seeking.