FdSet

Struct FdSet 

pub struct FdSet(/* private fields */);
File descriptor set for the virtual system

This is an implementation of the FdSet trait for the VirtualSystem. It represents a set of file descriptors that can be monitored for events such as readability or writability in the virtual system. Currently, the FdSet struct internally uses a BTreeSet to store the file descriptors, which allows for efficient insertion, removal, and lookup of file descriptors.

Implementations

Source

impl FdSet

pub fn len(&self) -> usize

Returns the number of file descriptors in the set.

pub fn is_empty(&self) -> bool

Returns whether the set is empty.

pub fn iter(&self) -> Iter<'_>

Returns an iterator over the file descriptors in the set.