#[non_exhaustive]pub struct Stat {
pub dev: u64,
pub ino: u64,
pub mode: Mode,
pub type: FileType,
pub nlink: u64,
pub uid: Uid,
pub gid: Gid,
pub size: u64,
}Expand description
File status
This type is a collection of file status information. It is similar to the
stat structure defined in the POSIX standard, but it is simplified and
does not include all fields of the stat structure.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dev: u64Device ID
ino: u64Inode number
mode: ModeAccess permissions
Note that this field does not include the file type bits.
The file type is stored in the type field.
type: FileTypeFile type
nlink: u64Number of hard links
uid: UidUser ID of the file owner
gid: GidGroup ID of the file owner
size: u64Length of the file in bytes
Implementations