SystemState

Struct SystemState 

pub struct SystemState {
    pub now: Option<Instant>,
    pub scheduled_wakers: ScheduledWakerQueue,
    pub times: CpuTimes,
    pub executor: Option<Rc<dyn Executor>>,
    pub processes: BTreeMap<Pid, Process>,
    pub foreground: Option<Pid>,
    pub file_system: FileSystem,
    pub home_dirs: HashMap<String, PathBuf>,
    pub path: UnixString,
}
State of the virtual system

Fields

now: Option<Instant>

Current time

To make sure scheduled wakers are woken up at the right time, use advance_time to update the current time instead of directly modifying this field.

scheduled_wakers: ScheduledWakerQueue

Priority queue of wakers scheduled to be woken up at specific times

times: CpuTimes

Consumed CPU time statistics

executor: Option<Rc<dyn Executor>>

Task manager that can execute asynchronous tasks

The virtual system uses this executor to run (virtual) child processes. If executor is None, VirtualSystem::new_child_process will fail.

processes: BTreeMap<Pid, Process>

Processes running in the system

foreground: Option<Pid>

Process group ID of the foreground process group

Note: The current implementation does not support the notion of controlling terminals and sessions. This item may be replaced with a more correct implementation in the future.

file_system: FileSystem

Collection of files existing in the virtual system

home_dirs: HashMap<String, PathBuf>

Map from user names to their home directory paths

VirtualSystem::getpwnam_dir looks up its argument in this dictionary.

path: UnixString

Standard path returned by VirtualSystem::confstr_path

Implementations

Source

impl SystemState

pub fn advance_time(&mut self, new_current_time: Instant)

Sets the current time to new_current_time and wakes up any wakers scheduled to be woken up by that time.

pub fn select_all(_: &RefCell<Self>)

👎Deprecated since 0.13.0:

you no longer need to call this function manually

Does nothing.

This function is a no-op and is only provided for backward compatibility. It is not necessary to call this function manually, as virtual processes are now automatically woken up when they are ready to make progress. If you have existing code that calls this function, you can safely remove those calls.

This function used to perform select on all processes in the system.