pub struct VirtualSystem {
pub state: Rc<RefCell<SystemState>>,
pub process_id: Pid,
}Expand description
Simulated system
See the module-level documentation to grasp a basic understanding of
VirtualSystem.
A VirtualSystem instance has two members: state and process_id. The
former is a SystemState that effectively contains the whole state of the
system. The state is contained in Rc so that virtual processes can share
the same state. The latter is a process ID that identifies a process calling
the system interfaces.
When you clone a virtual system, the clone will have the same process_id
and state as the original. To simulate the fork system call, you should
call a method of the Fork trait implemented by VirtualSystem.
Fields
state: Rc<RefCell<SystemState>>State of the system.
process_id: PidProcess ID of the process that is interacting with the system.
Implementations
Sourceimpl VirtualSystem
impl VirtualSystem
Sourcepub fn new() -> VirtualSystem
pub fn new() -> VirtualSystem
Creates a virtual system with an almost empty state.
The process_id of the returned VirtualSystem will be 2.
(Process ID 1 has special meaning in some system calls, so we don’t use
it as a default value.)
The state of the returned VirtualSystem will have a Process with
process ID 2 in the process set (SystemState::processes). The file
system will contain files named /dev/stdin, /dev/stdout, and
/dev/stderr that are opened in the process with file descriptor 0, 1,
and 2, respectively. The file system also contains an empty directory
/tmp.
Sourcepub fn current_process(&self) -> Ref<'_, Process>
pub fn current_process(&self) -> Ref<'_, Process>
Finds the current process from the system state.
Panics
This function will panic if it cannot find a process having
self.process_id.
Sourcepub fn current_process_mut(&self) -> RefMut<'_, Process>
pub fn current_process_mut(&self) -> RefMut<'_, Process>
Finds the current process from the system state.
Panics
This function will panic if it cannot find a process having
self.process_id.
Sourcepub fn get_open_file_description(
&self,
fd: Fd,
) -> Result<Rc<RefCell<OpenFileDescription>>>
pub fn get_open_file_description( &self, fd: Fd, ) -> Result<Rc<RefCell<OpenFileDescription>>>
Returns the open file description for the given FD.
This is a helper function for obtaining the open file description for a
given file descriptor in the current process.
Returns Err(Errno::EBADF) if the FD is not open.
Sourcepub fn with_open_file_description<F, R>(&self, fd: Fd, f: F) -> Result<R>
pub fn with_open_file_description<F, R>(&self, fd: Fd, f: F) -> Result<R>
Calls the given closure passing the open file description for the FD.
This is a helper function for performing an operation on the open file description for a given file descriptor in the current process. The closure is passed a reference to the open file description, and can perform any operation on it, such as checking its state. The return value of the closure is returned as the result of this function.
Returns Err(Errno::EBADF) if the FD is not open.
Panics if the open file description is already mutably borrowed.
Sourcepub fn with_open_file_description_mut<F, R>(&self, fd: Fd, f: F) -> Result<R>
pub fn with_open_file_description_mut<F, R>(&self, fd: Fd, f: F) -> Result<R>
Calls the given closure passing the open file description for the FD.
This is a helper function for performing a mutable operation on the open file description for a given file descriptor in the current process. The closure is passed a mutable reference to the open file description, and can perform any operation on it, such as reading and writing. The return value of the closure is returned as the result of this function.
Returns Err(Errno::EBADF) if the FD is not open.
Panics if the open file description is already borrowed.