pub struct FdReader2<S> { /* private fields */ }Expand description
Input function that reads from a file descriptor
An instance of FdReader2<S> contains a system of type S that is used to
read from the file descriptor. The system must implement the Read trait to
allow the reading operation.
Although FdReader2 implements Clone, cloning an instance does not allow
you to replay the input later. If the system is contained in Rc, for
example, reading from one instance will affect subsequent reads from the
other, since they share the same system and file descriptor.
This struct is named FdReader2 to distinguish it from FdReader, an older
implementation that existed before the Concurrent system was implemented.
The FdReader struct has been removed, but the name FdReader2 is kept for
backward compatibility.
Implementations