pub struct FdReader2<S> { /* private fields */ }Expand description
Input function that reads from a file descriptor
An instance of FdReader2<S> contains a Rc<Concurrent<S>> to read input
from a file descriptor.
Although FdReader2 implements Clone, it does not mean you can create and
keep a copy of a FdReader2 instance to replay the input later. Since both
the original and clone share the same Concurrent<S>, reading a line from
one instance will affect the next read from the other.
FdReader2 is a variant of FdReader that depends on
Concurrent<S> instead of SharedSystem.
Implementations