pub fn classify<S, E: ClassifyEnv<S>>(env: &E, name: &str) -> Target<S>Expand description
Determines the type of command target without performing a full search.
This function is a simplified version of search that only classifies the
command name into one of the target types. It does not return the actual
target path, so it is more efficient than search if the caller only needs
to know the type of target. However, since the function does not search for
external utilities, it cannot determine whether a substitutive built-in or
an external utility is the actual target. This function always assumes that
searching for an external utility would succeed and returns a target with
an empty path in such cases.