Utility for starting subshells
This module defines Subshell, a builder for starting a subshell. It is
constructed with a function you want to run in a subshell.
After configuring the builder with some options, you can
start the subshell.
Subshell is implemented as a wrapper around Fork::new_child_process.
You should prefer Subshell for the purpose of creating a subshell because
it helps to arrange the child process properly.
Structs
- Subshell
- Subshell builder
Enums
- JobControl
- Job state of a newly created subshell