IsExecutableFile

Trait IsExecutableFile 

pub trait IsExecutableFile {
    // Required method
    fn is_executable_file(&self, path: &CStr) -> bool;
}
Trait for checking if a file is executable

This trait declares the is_executable_file method, which checks whether a filepath points to an executable regular file. This trait is separate from the Fstat trait because the implementation depends on the faccessat system call.

Required Methods

fn is_executable_file(&self, path: &CStr) -> bool

Whether there is an executable regular file at the specified path.

Implementations on Foreign Types

Source

impl<S: IsExecutableFile> IsExecutableFile for Rc<S>

Delegates the IsExecutableFile trait to the contained instance of S

Source

fn is_executable_file(&self, path: &CStr) -> bool

Implementors

Source

impl IsExecutableFile for RealSystem

Source

impl IsExecutableFile for VirtualSystem

Source

impl<S> IsExecutableFile for Concurrent<S>

Source

impl<T: IsExecutableFile> IsExecutableFile for SharedSystem<T>

Delegates IsExecutableFile methods to the contained implementor.