pub trait System:
CaughtSignals
+ Chdir
+ Clock
+ Close
+ Debug
+ Dup
+ Exec
+ Exit
+ Fcntl
+ Fork
+ Fstat
+ GetCwd
+ GetPid
+ GetPw
+ GetRlimit
+ GetUid
+ IsExecutableFile
+ Isatty
+ Open
+ Pipe
+ Read
+ Seek
+ Select
+ SendSignal
+ SetPgid
+ SetRlimit
+ ShellPath
+ Sigaction
+ Sigmask
+ Signals
+ Sysconf
+ TcGetPgrp
+ TcSetPgrp
+ Times
+ Umask
+ Wait
+ Write { }👎Deprecated since 0.11.0:
use smaller, more specialized traits declared in the system module instead
Utility trait that aggregates all the traits in this module
The System trait defines a collection of methods to access the underlying
operating system from the shell as an application program. See the
module-level documentation for more details.
This trait is now deprecated in favor of depending on specific traits that declare the methods needed by the user code, which promotes interface segregation.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.