pub type ChildProcessTask<S> = Box<dyn for<'a> FnOnce(&'a mut Env<S>) -> Pin<Box<dyn Future<Output = Infallible> + 'a>>>;Expand description
Task executed in a child process
This is an argument passed to a ChildProcessStarter. The task is
executed in a child process initiated by the starter. The environment passed
to the task is a clone of the parent environment, but it has a different
process ID than the parent.
Note that the output type of the task is Infallible. This is to ensure
that the task exits cleanly or
kills itself with a signal.
Aliased Type
pub struct ChildProcessTask<S>(/* private fields */);