pub struct FdSet(/* private fields */);Expand description
File descriptor set for the virtual system
This is an implementation of the FdSet trait for the
VirtualSystem. It represents a set of file
descriptors that can be monitored for events such as readability or
writability in the virtual system. Currently, the FdSet struct internally
uses a BTreeSet to store the file descriptors, which allows for efficient
insertion, removal, and lookup of file descriptors.
Implementations